summaryrefslogtreecommitdiff
path: root/ports/cortex_m33/iar/src
diff options
context:
space:
mode:
Diffstat (limited to 'ports/cortex_m33/iar/src')
-rw-r--r--ports/cortex_m33/iar/src/tx_initialize_low_level.s344
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_context_restore.s137
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_context_save.s137
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_interrupt_control.s145
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_interrupt_disable.s138
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_interrupt_restore.s136
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_schedule.s51
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_secure_stack.c4
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_secure_stack_allocate.s138
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_secure_stack_free.s133
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_stack_build.s256
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_stack_error_handler.c12
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_stack_error_notify.c6
-rw-r--r--ports/cortex_m33/iar/src/tx_thread_system_return.s166
-rw-r--r--ports/cortex_m33/iar/src/tx_timer_interrupt.s451
-rw-r--r--ports/cortex_m33/iar/src/txe_thread_secure_stack_allocate.c8
-rw-r--r--ports/cortex_m33/iar/src/txe_thread_secure_stack_free.c5
17 files changed, 1128 insertions, 1139 deletions
diff --git a/ports/cortex_m33/iar/src/tx_initialize_low_level.s b/ports/cortex_m33/iar/src/tx_initialize_low_level.s
index 27922ca2..1ba0a002 100644
--- a/ports/cortex_m33/iar/src/tx_initialize_low_level.s
+++ b/ports/cortex_m33/iar/src/tx_initialize_low_level.s
@@ -1,26 +1,25 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Initialize */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Initialize */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
EXTERN _tx_thread_system_stack_ptr
EXTERN _tx_initialize_unused_memory
EXTERN _tx_timer_interrupt
@@ -28,126 +27,112 @@
EXTERN __vector_table
EXTERN _tx_thread_current_ptr
EXTERN _tx_thread_stack_error_handler
-;
-;
+
SYSTEM_CLOCK EQU 96000000
SYSTICK_CYCLES EQU ((SYSTEM_CLOCK / 100) -1)
-;
-;
+
RSEG FREE_MEM:DATA
PUBLIC __tx_free_memory_start
__tx_free_memory_start
DS32 4
-;
-;
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_initialize_low_level Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is responsible for any low-level processor */
-;/* initialization, including setting up interrupt vectors, setting */
-;/* up a periodic timer interrupt source, saving the system stack */
-;/* pointer for use in ISR processing later, and finding the first */
-;/* available RAM memory address for tx_application_define. */
-;/* */
-;/* INPUT */
-;/* */
-;/* None */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* None */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* _tx_initialize_kernel_enter ThreadX entry function */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_initialize_low_level(VOID)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_initialize_low_level Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is responsible for any low-level processor */
+/* initialization, including setting up interrupt vectors, setting */
+/* up a periodic timer interrupt source, saving the system stack */
+/* pointer for use in ISR processing later, and finding the first */
+/* available RAM memory address for tx_application_define. */
+/* */
+/* INPUT */
+/* */
+/* None */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* None */
+/* */
+/* CALLED BY */
+/* */
+/* _tx_initialize_kernel_enter ThreadX entry function */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_initialize_low_level(VOID)
+// {
PUBLIC _tx_initialize_low_level
_tx_initialize_low_level:
-;
-; /* Disable interrupts during ThreadX initialization. */
-;
+
+ /* Disable interrupts during ThreadX initialization. */
CPSID i
-;
-; /* Set base of available memory to end of non-initialised RAM area. */
-;
- LDR r0, =_tx_initialize_unused_memory ; Build address of unused memory pointer
- LDR r1, =__tx_free_memory_start ; Build first free address
- STR r1, [r0] ; Setup first unused memory pointer
-;
-; /* Setup Vector Table Offset Register. */
-;
- MOV r0, #0xE000E000 ; Build address of NVIC registers
- LDR r1, =__vector_table ; Pickup address of vector table
- STR r1, [r0, #0xD08] ; Set vector table address
-;
-; /* Enable the cycle count register. */
-;
-; LDR r0, =0xE0001000 ; Build address of DWT register
-; LDR r1, [r0] ; Pickup the current value
-; ORR r1, r1, #1 ; Set the CYCCNTENA bit
-; STR r1, [r0] ; Enable the cycle count register
-;
-; /* Set system stack pointer from vector value. */
-;
- LDR r0, =_tx_thread_system_stack_ptr ; Build address of system stack pointer
- LDR r1, =__vector_table ; Pickup address of vector table
- LDR r1, [r1] ; Pickup reset stack pointer
- STR r1, [r0] ; Save system stack pointer
-;
-; /* Configure SysTick. */
-;
- MOV r0, #0xE000E000 ; Build address of NVIC registers
+
+ /* Set base of available memory to end of non-initialised RAM area. */
+ LDR r0, =_tx_initialize_unused_memory // Build address of unused memory pointer
+ LDR r1, =__tx_free_memory_start // Build first free address
+ STR r1, [r0] // Setup first unused memory pointer
+
+ /* Setup Vector Table Offset Register. */
+ MOV r0, #0xE000E000 // Build address of NVIC registers
+ LDR r1, =__vector_table // Pickup address of vector table
+ STR r1, [r0, #0xD08] // Set vector table address
+
+ /* Enable the cycle count register. */
+// LDR r0, =0xE0001000 // Build address of DWT register
+// LDR r1, [r0] // Pickup the current value
+// ORR r1, r1, #1 // Set the CYCCNTENA bit
+// STR r1, [r0] // Enable the cycle count register
+
+ /* Set system stack pointer from vector value. */
+ LDR r0, =_tx_thread_system_stack_ptr // Build address of system stack pointer
+ LDR r1, =__vector_table // Pickup address of vector table
+ LDR r1, [r1] // Pickup reset stack pointer
+ STR r1, [r0] // Save system stack pointer
+
+ /* Configure SysTick. */
+ MOV r0, #0xE000E000 // Build address of NVIC registers
LDR r1, =SYSTICK_CYCLES
- STR r1, [r0, #0x14] ; Setup SysTick Reload Value
- MOV r1, #0x7 ; Build SysTick Control Enable Value
- STR r1, [r0, #0x10] ; Setup SysTick Control
-;
-; /* Configure handler priorities. */
-;
- LDR r1, =0x00000000 ; Rsrv, UsgF, BusF, MemM
- STR r1, [r0, #0xD18] ; Setup System Handlers 4-7 Priority Registers
+ STR r1, [r0, #0x14] // Setup SysTick Reload Value
+ MOV r1, #0x7 // Build SysTick Control Enable Value
+ STR r1, [r0, #0x10] // Setup SysTick Control
- LDR r1, =0xFF000000 ; SVCl, Rsrv, Rsrv, Rsrv
- STR r1, [r0, #0xD1C] ; Setup System Handlers 8-11 Priority Registers
- ; Note: SVC must be lowest priority, which is 0xFF
+ /* Configure handler priorities. */
+ LDR r1, =0x00000000 // Rsrv, UsgF, BusF, MemM
+ STR r1, [r0, #0xD18] // Setup System Handlers 4-7 Priority Registers
+ LDR r1, =0xFF000000 // SVCl, Rsrv, Rsrv, Rsrv
+ STR r1, [r0, #0xD1C] // Setup System Handlers 8-11 Priority Registers
+ // Note: SVC must be lowest priority, which is 0xFF
+ LDR r1, =0x40FF0000 // SysT, PnSV, Rsrv, DbgM
+ STR r1, [r0, #0xD20] // Setup System Handlers 12-15 Priority Registers
+ // Note: PnSV must be lowest priority, which is 0xFF
- LDR r1, =0x40FF0000 ; SysT, PnSV, Rsrv, DbgM
- STR r1, [r0, #0xD20] ; Setup System Handlers 12-15 Priority Registers
- ; Note: PnSV must be lowest priority, which is 0xFF
-;
-; /* Return to caller. */
-;
+ /* Return to caller. */
BX lr
-;}
-;
-;
-;/* Define shells for each of the unused vectors. */
-;
+// }
+
+
+/* Define shells for each of the unused vectors. */
+
PUBLIC __tx_BadHandler
__tx_BadHandler:
B __tx_BadHandler
@@ -155,30 +140,39 @@ __tx_BadHandler:
PUBLIC __tx_IntHandler
__tx_IntHandler:
-; VOID InterruptHandler (VOID)
-; {
- PUSH {r0,lr} ; Save LR (and dummy r0 to maintain stack alignment)
-
-; /* Do interrupt handler work here */
-; /* .... */
-
+// VOID InterruptHandler (VOID)
+// {
+ PUSH {r0,lr} // Save LR (and dummy r0 to maintain stack alignment)
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ BL _tx_execution_isr_enter // Call the ISR enter function
+#endif
+ /* Do interrupt handler work here */
+ /* .... */
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ BL _tx_execution_isr_exit // Call the ISR exit function
+#endif
POP {r0,lr}
- BX LR
-; }
+ BX lr
+// }
PUBLIC __tx_SysTickHandler
PUBLIC SysTick_Handler
SysTick_Handler:
__tx_SysTickHandler:
-; VOID TimerInterruptHandler (VOID)
-; {
-;
- PUSH {r0,lr} ; Save LR (and dummy r0 to maintain stack alignment)
+// VOID TimerInterruptHandler (VOID)
+// {
+ PUSH {r0,lr} // Save LR (and dummy r0 to maintain stack alignment)
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ BL _tx_execution_isr_enter // Call the ISR enter function
+#endif
BL _tx_timer_interrupt
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ BL _tx_execution_isr_exit // Call the ISR exit function
+#endif
POP {r0,lr}
- BX LR
-; }
+ BX lr
+// }
PUBLIC HardFault_Handler
HardFault_Handler:
@@ -187,48 +181,48 @@ HardFault_Handler:
PUBLIC UsageFault_Handler
UsageFault_Handler:
- CPSID i ; Disable interrupts
- ; Check for stack limit fault
- LDR r0, =0xE000ED28 ; CFSR address
- LDR r1,[r0] ; Pick up CFSR
- TST r1, #0x00100000 ; Check for Stack Overflow
+ CPSID i // Disable interrupts
+ // Check for stack limit fault
+ LDR r0, =0xE000ED28 // CFSR address
+ LDR r1,[r0] // Pick up CFSR
+ TST r1, #0x00100000 // Check for Stack Overflow
_unhandled_usage_loop
- BEQ _unhandled_usage_loop ; If not stack overflow then loop
+ BEQ _unhandled_usage_loop // If not stack overflow then loop
- ; Handle stack overflow
- STR r1, [r0] ; Clear CFSR flag(s)
+ // Handle stack overflow
+ STR r1, [r0] // Clear CFSR flag(s)
#ifdef __ARMVFP__
- LDR r0, =0xE000EF34 ; Cleanup FPU context: Load FPCCR address
- LDR r1, [r0] ; Load FPCCR
- BIC r1, r1, #1 ; Clear the lazy preservation active bit
- STR r1, [r0] ; Store the value
+ LDR r0, =0xE000EF34 // Cleanup FPU context: Load FPCCR address
+ LDR r1, [r0] // Load FPCCR
+ BIC r1, r1, #1 // Clear the lazy preservation active bit
+ STR r1, [r0] // Store the value
#endif
- MOV32 r0, _tx_thread_current_ptr ; Build current thread pointer address
- LDR r0,[r0] ; Pick up current thread pointer
- PUSH {r0,lr} ; Save LR (and r0 to maintain stack alignment)
- BL _tx_thread_stack_error_handler ; Call ThreadX/user handler
- POP {r0,lr} ; Restore LR and dummy reg
+ LDR r0, =_tx_thread_current_ptr // Build current thread pointer address
+ LDR r0,[r0] // Pick up current thread pointer
+ PUSH {r0,lr} // Save LR (and r0 to maintain stack alignment)
+ BL _tx_thread_stack_error_handler // Call ThreadX/user handler
+ POP {r0,lr} // Restore LR and dummy reg
-#ifdef TX_ENABLE_EXECUTION_CHANGE_NOTIFY
- ; Call the thread exit function to indicate the thread is no longer executing.
- PUSH {r0, lr} ; Save LR (and r0 just for alignment)
- BL _tx_execution_thread_exit ; Call the thread exit function
- POP {r0, lr} ; Recover LR
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ // Call the thread exit function to indicate the thread is no longer executing.
+ PUSH {r0, lr} // Save LR (and r0 just for alignment)
+ BL _tx_execution_thread_exit // Call the thread exit function
+ POP {r0, lr} // Recover LR
#endif
- MOV r1, #0 ; Build NULL value
- LDR r0, =_tx_thread_current_ptr ; Pickup address of current thread pointer
- STR r1, [r0] ; Clear current thread pointer
+ MOV r1, #0 // Build NULL value
+ LDR r0, =_tx_thread_current_ptr // Pickup address of current thread pointer
+ STR r1, [r0] // Clear current thread pointer
- ; Return from UsageFault_Handler exception
- LDR r0, =0xE000ED04 ; Load ICSR
- LDR r1, =0x10000000 ; Set PENDSVSET bit
- STR r1, [r0] ; Store ICSR
- DSB ; Wait for memory access to complete
- CPSIE i ; Enable interrupts
- BX lr ; Return from exception
+ // Return from UsageFault_Handler exception
+ LDR r0, =0xE000ED04 // Load ICSR
+ LDR r1, =0x10000000 // Set PENDSVSET bit
+ STR r1, [r0] // Store ICSR
+ DSB // Wait for memory access to complete
+ CPSIE i // Enable interrupts
+ BX lr // Return from exception
PUBLIC __tx_NMIHandler
diff --git a/ports/cortex_m33/iar/src/tx_thread_interrupt_control.s b/ports/cortex_m33/iar/src/tx_thread_interrupt_control.s
index faa06ed3..45e5c5de 100644
--- a/ports/cortex_m33/iar/src/tx_thread_interrupt_control.s
+++ b/ports/cortex_m33/iar/src/tx_thread_interrupt_control.s
@@ -1,77 +1,78 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_interrupt_control Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is responsible for changing the interrupt lockout */
-;/* posture of the system. */
-;/* */
-;/* INPUT */
-;/* */
-;/* new_posture New interrupt lockout posture */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* old_posture Old interrupt lockout posture */
-;/* */
-;/* CALLS */
-;/* */
-;/* None */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* Application Code */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;UINT _tx_thread_interrupt_control(UINT new_posture)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_interrupt_control Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is responsible for changing the interrupt lockout */
+/* posture of the system. */
+/* */
+/* INPUT */
+/* */
+/* new_posture New interrupt lockout posture */
+/* */
+/* OUTPUT */
+/* */
+/* old_posture Old interrupt lockout posture */
+/* */
+/* CALLS */
+/* */
+/* None */
+/* */
+/* CALLED BY */
+/* */
+/* Application Code */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// UINT _tx_thread_interrupt_control(UINT new_posture)
+// {
PUBLIC _tx_thread_interrupt_control
_tx_thread_interrupt_control:
-;
-; /* Pickup current interrupt lockout posture. */
-;
- MRS r1, PRIMASK
- MSR PRIMASK, r0
- MOV r0, r1
- BX lr
-;
-;}
+#ifdef TX_PORT_USE_BASEPRI
+ MRS r1, BASEPRI // Pickup current interrupt posture
+ MSR BASEPRI, r0 // Apply the new interrupt posture
+ MOV r0, r1 // Transfer old to return register
+#else
+ MRS r1, PRIMASK // Pickup current interrupt lockout
+ MSR PRIMASK, r0 // Apply the new interrupt lockout
+ MOV r0, r1 // Transfer old to return register
+#endif
+ BX lr // Return to caller
+// }
END
diff --git a/ports/cortex_m33/iar/src/tx_thread_interrupt_disable.s b/ports/cortex_m33/iar/src/tx_thread_interrupt_disable.s
index fb01c9d1..68421f0e 100644
--- a/ports/cortex_m33/iar/src/tx_thread_interrupt_disable.s
+++ b/ports/cortex_m33/iar/src/tx_thread_interrupt_disable.s
@@ -1,76 +1,78 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_interrupt_disable Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is responsible for disabling interrupts and returning */
-;/* the previous interrupt lockout posture. */
-;/* */
-;/* INPUT */
-;/* */
-;/* old_posture Old interrupt lockout posture */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* None */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* Application Code */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;UINT _tx_thread_interrupt_disable(UINT new_posture)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_interrupt_disable Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is responsible for disabling interrupts and returning */
+/* the previous interrupt lockout posture. */
+/* */
+/* INPUT */
+/* */
+/* None */
+/* */
+/* OUTPUT */
+/* */
+/* old_posture Old interrupt lockout posture */
+/* */
+/* CALLS */
+/* */
+/* None */
+/* */
+/* CALLED BY */
+/* */
+/* Application Code */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// UINT _tx_thread_interrupt_disable(VOID)
+// {
PUBLIC _tx_thread_interrupt_disable
_tx_thread_interrupt_disable:
-;
-; /* Return current interrupt lockout posture. */
-;
+ /* Return current interrupt lockout posture. */
+#ifdef TX_PORT_USE_BASEPRI
+ MRS r0, BASEPRI
+ LDR r1, =TX_PORT_BASEPRI
+ MSR BASEPRI, r1
+#else
MRS r0, PRIMASK
CPSID i
+#endif
BX lr
-;
-;}
+// }
END
diff --git a/ports/cortex_m33/iar/src/tx_thread_interrupt_restore.s b/ports/cortex_m33/iar/src/tx_thread_interrupt_restore.s
index ce4da3c3..c590eb13 100644
--- a/ports/cortex_m33/iar/src/tx_thread_interrupt_restore.s
+++ b/ports/cortex_m33/iar/src/tx_thread_interrupt_restore.s
@@ -1,75 +1,75 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_interrupt_restore Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is responsible for restoring the previous */
-;/* interrupt lockout posture. */
-;/* */
-;/* INPUT */
-;/* */
-;/* None */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* previous_posture Previous interrupt posture */
-;/* */
-;/* CALLS */
-;/* */
-;/* None */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* Application Code */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_thread_interrupt_restore(UINT new_posture)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_interrupt_restore Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is responsible for restoring the previous */
+/* interrupt lockout posture. */
+/* */
+/* INPUT */
+/* */
+/* previous_posture Previous interrupt posture */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* None */
+/* */
+/* CALLED BY */
+/* */
+/* Application Code */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_thread_interrupt_restore(UINT previous_posture)
+// {
PUBLIC _tx_thread_interrupt_restore
_tx_thread_interrupt_restore:
-;
-; /* Restore previous interrupt lockout posture. */
-;
+ /* Restore previous interrupt lockout posture. */
+#ifdef TX_PORT_USE_BASEPRI
+ MSR BASEPRI, r0
+#else
MSR PRIMASK, r0
+#endif
BX lr
-;
-;}
+// }
END
diff --git a/ports/cortex_m33/iar/src/tx_thread_schedule.s b/ports/cortex_m33/iar/src/tx_thread_schedule.s
index d9accd71..003f8114 100644
--- a/ports/cortex_m33/iar/src/tx_thread_schedule.s
+++ b/ports/cortex_m33/iar/src/tx_thread_schedule.s
@@ -108,7 +108,6 @@ _tx_thread_schedule:
CPSIE i
/* Enter the scheduler for the first time. */
-
MOV r0, #0x10000000 // Load PENDSVSET bit
MOV r1, #0xE000E000 // Load NVIC base
STR r0, [r1, #0xD04] // Set PENDSVBIT in ICSR
@@ -127,7 +126,7 @@ __tx_wait_here:
PendSV_Handler:
__tx_ts_handler:
-#ifdef TX_ENABLE_EXECUTION_CHANGE_NOTIFY
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
/* Call the thread exit function to indicate the thread is no longer executing. */
CPSID i // Disable interrupts
PUSH {r0, lr} // Save LR (and r0 just for alignment)
@@ -135,6 +134,7 @@ __tx_ts_handler:
POP {r0, lr} // Recover LR
CPSIE i // Enable interrupts
#endif
+
LDR r0, =_tx_thread_current_ptr // Build current thread pointer address
LDR r2, =_tx_thread_execute_ptr // Build execute thread pointer address
MOV r3, #0 // Build NULL value
@@ -211,7 +211,7 @@ __tx_ts_restore:
STR r5, [r4] // Setup global time-slice
-#ifdef TX_ENABLE_EXECUTION_CHANGE_NOTIFY
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
/* Call the thread entry function to indicate the thread is executing. */
PUSH {r0, r1} // Save r0 and r1
BL _tx_execution_thread_enter // Call the thread execution enter function
@@ -243,7 +243,6 @@ _skip_vfp_restore:
LDMIA r12!, {r4-r11} // Recover thread's registers
MSR PSP, r12 // Setup the thread's stack pointer
- /* Return to thread. */
BX lr // Return to thread!
/* The following is the idle wait processing... in this case, no threads are ready for execution and the
@@ -287,50 +286,51 @@ __tx_ts_ready:
/* Re-enable interrupts and restore new thread. */
CPSIE i // Enable interrupts
B __tx_ts_restore // Restore the thread
+// }
#if (!defined(TX_SINGLE_MODE_SECURE) && !defined(TX_SINGLE_MODE_NON_SECURE))
// SVC_Handler is not needed when ThreadX is running in single mode.
PUBLIC SVC_Handler
SVC_Handler:
- TST lr, #0x04 // Determine return stack from EXC_RETURN bit 2
+ TST lr, #0x04 // Determine return stack from EXC_RETURN bit 2
ITE EQ
- MRSEQ r0, MSP // Get MSP if return stack is MSP
- MRSNE r0, PSP // Get PSP if return stack is PSP
+ MRSEQ r0, MSP // Get MSP if return stack is MSP
+ MRSNE r0, PSP // Get PSP if return stack is PSP
- LDR r1, [r0,#24] // Load saved PC from stack
- LDRB r1, [r1,#-2] // Load SVC number
+ LDR r1, [r0,#24] // Load saved PC from stack
+ LDRB r1, [r1,#-2] // Load SVC number
- CMP r1, #1 // Is it a secure stack allocate request?
- BEQ _tx_svc_secure_alloc // Yes, go there
+ CMP r1, #1 // Is it a secure stack allocate request?
+ BEQ _tx_svc_secure_alloc // Yes, go there
- CMP r1, #2 // Is it a secure stack free request?
- BEQ _tx_svc_secure_free // Yes, go there
+ CMP r1, #2 // Is it a secure stack free request?
+ BEQ _tx_svc_secure_free // Yes, go there
- CMP r1, #3 // Is it a secure stack init request?
- BEQ _tx_svc_secure_init // Yes, go there
+ CMP r1, #3 // Is it a secure stack init request?
+ BEQ _tx_svc_secure_init // Yes, go there
// Unknown SVC argument - just return
BX lr
_tx_svc_secure_alloc:
- PUSH {r0,lr} // Save SP and EXC_RETURN
- LDM r0, {r0-r3} // Load function parameters from stack
+ PUSH {r0,lr} // Save SP and EXC_RETURN
+ LDM r0, {r0-r3} // Load function parameters from stack
BL _tx_thread_secure_mode_stack_allocate
- POP {r12,lr} // Restore SP and EXC_RETURN
- STR r0,[r12] // Store function return value
+ POP {r12,lr} // Restore SP and EXC_RETURN
+ STR r0,[r12] // Store function return value
BX lr
_tx_svc_secure_free:
- PUSH {r0,lr} // Save SP and EXC_RETURN
- LDM r0, {r0-r3} // Load function parameters from stack
+ PUSH {r0,lr} // Save SP and EXC_RETURN
+ LDM r0, {r0-r3} // Load function parameters from stack
BL _tx_thread_secure_mode_stack_free
- POP {r12,lr} // Restore SP and EXC_RETURN
- STR r0,[r12] // Store function return value
+ POP {r12,lr} // Restore SP and EXC_RETURN
+ STR r0,[r12] // Store function return value
BX lr
_tx_svc_secure_init:
- PUSH {r0,lr} // Save SP and EXC_RETURN
+ PUSH {r0,lr} // Save SP and EXC_RETURN
BL _tx_thread_secure_mode_stack_initialize
- POP {r12,lr} // Restore SP and EXC_RETURN
+ POP {r12,lr} // Restore SP and EXC_RETURN
BX lr
#endif // End of ifndef TX_SINGLE_MODE_SECURE, TX_SINGLE_MODE_NON_SECURE
@@ -339,5 +339,4 @@ _tx_svc_secure_init:
_tx_vfp_access:
VMOV.F32 s0, s0 // Simply access the VFP
BX lr // Return to caller
-
END
diff --git a/ports/cortex_m33/iar/src/tx_thread_secure_stack.c b/ports/cortex_m33/iar/src/tx_thread_secure_stack.c
index ab9fdedc..f48ff16d 100644
--- a/ports/cortex_m33/iar/src/tx_thread_secure_stack.c
+++ b/ports/cortex_m33/iar/src/tx_thread_secure_stack.c
@@ -304,7 +304,7 @@ UINT _tx_thread_secure_mode_stack_free(TX_THREAD *thread_ptr)
{
UINT status;
TX_THREAD_SECURE_STACK_INFO *info_ptr;
-
+
status = TX_SUCCESS;
/* Pickup stack info from thread. */
@@ -389,7 +389,7 @@ void _tx_thread_secure_stack_context_save(TX_THREAD *thread_ptr)
{
TX_THREAD_SECURE_STACK_INFO *info_ptr;
ULONG sp;
-
+
/* This function should be called from scheduler only. */
if (__get_IPSR() == 0)
{
diff --git a/ports/cortex_m33/iar/src/tx_thread_secure_stack_allocate.s b/ports/cortex_m33/iar/src/tx_thread_secure_stack_allocate.s
index 817746bb..35923943 100644
--- a/ports/cortex_m33/iar/src/tx_thread_secure_stack_allocate.s
+++ b/ports/cortex_m33/iar/src/tx_thread_secure_stack_allocate.s
@@ -1,82 +1,80 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_secure_stack_allocate Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function enters the SVC handler to allocate a secure stack. */
-;/* */
-;/* INPUT */
-;/* */
-;/* thread_ptr Thread control block pointer */
-;/* stack_size Size of secure stack to */
-;/* allocate */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* status Actual completion status */
-;/* */
-;/* CALLS */
-;/* */
-;/* SVC 1 */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* Application Code */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;UINT _tx_thread_secure_stack_allocate(TX_THREAD *thread_ptr, ULONG stack_size)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_secure_stack_allocate Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function enters the SVC handler to allocate a secure stack. */
+/* */
+/* INPUT */
+/* */
+/* thread_ptr Thread control block pointer */
+/* stack_size Size of secure stack to */
+/* allocate */
+/* */
+/* OUTPUT */
+/* */
+/* status Actual completion status */
+/* */
+/* CALLS */
+/* */
+/* SVC 1 */
+/* */
+/* CALLED BY */
+/* */
+/* Application Code */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// UINT _tx_thread_secure_stack_allocate(TX_THREAD *thread_ptr, ULONG stack_size)
+// {
EXPORT _tx_thread_secure_stack_allocate
_tx_thread_secure_stack_allocate:
#if !defined(TX_SINGLE_MODE_SECURE) && !defined(TX_SINGLE_MODE_NON_SECURE)
- MRS r3, PRIMASK ; Save interrupt mask
- CPSIE i ; Enable interrupts for SVC call
+ MRS r3, PRIMASK // Save interrupt mask
+ CPSIE i // Enable interrupts for SVC call
SVC 1
- CMP r3, #0 ; If interrupts enabled, just return
+ CMP r3, #0 // If interrupts enabled, just return
BEQ _alloc_return_interrupt_enabled
- CPSID i ; Otherwise, disable interrupts
+ CPSID i // Otherwise, disable interrupts
#else
- MOV32 r0, #0xFF ; Feature not enabled
+ MOV r0, #0xFF // Feature not enabled
#endif
_alloc_return_interrupt_enabled
BX lr
-
END
diff --git a/ports/cortex_m33/iar/src/tx_thread_secure_stack_free.s b/ports/cortex_m33/iar/src/tx_thread_secure_stack_free.s
index 204b40c2..851f3621 100644
--- a/ports/cortex_m33/iar/src/tx_thread_secure_stack_free.s
+++ b/ports/cortex_m33/iar/src/tx_thread_secure_stack_free.s
@@ -1,78 +1,77 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_secure_stack_free Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function enters the SVC handler to free a secure stack. */
-;/* */
-;/* INPUT */
-;/* */
-;/* thread_ptr Thread control block pointer */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* status Actual completion status */
-;/* */
-;/* CALLS */
-;/* */
-;/* SVC 2 */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* Application Code */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;UINT _tx_thread_secure_stack_free(TX_THREAD *thread_ptr)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_secure_stack_free Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function enters the SVC handler to free a secure stack. */
+/* */
+/* INPUT */
+/* */
+/* thread_ptr Thread control block pointer */
+/* */
+/* OUTPUT */
+/* */
+/* status Actual completion status */
+/* */
+/* CALLS */
+/* */
+/* SVC 2 */
+/* */
+/* CALLED BY */
+/* */
+/* Application Code */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// UINT _tx_thread_secure_stack_free(TX_THREAD *thread_ptr)
+// {
EXPORT _tx_thread_secure_stack_free
_tx_thread_secure_stack_free:
#if !defined(TX_SINGLE_MODE_SECURE) && !defined(TX_SINGLE_MODE_NON_SECURE)
- MRS r3, PRIMASK ; Save interrupt mask
- CPSIE i ; Enable interrupts for SVC call
+ MRS r3, PRIMASK // Save interrupt mask
+ CPSIE i // Enable interrupts for SVC call
SVC 2
- CMP r3, #0 ; If interrupts enabled, just return
+ CMP r3, #0 // If interrupts enabled, just return
BEQ _free_return_interrupt_enabled
- CPSID i ; Otherwise, disable interrupts
+ CPSID i // Otherwise, disable interrupts
#else
- MOV32 r0, #0xFF ; Feature not enabled
+ MOV r0, #0xFF // Feature not enabled
#endif
_free_return_interrupt_enabled
BX lr
diff --git a/ports/cortex_m33/iar/src/tx_thread_stack_build.s b/ports/cortex_m33/iar/src/tx_thread_stack_build.s
index e891b8ff..d4131978 100644
--- a/ports/cortex_m33/iar/src/tx_thread_stack_build.s
+++ b/ports/cortex_m33/iar/src/tx_thread_stack_build.s
@@ -1,137 +1,135 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_stack_build Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function builds a stack frame on the supplied thread's stack. */
-;/* The stack frame results in a fake interrupt return to the supplied */
-;/* function pointer. */
-;/* */
-;/* INPUT */
-;/* */
-;/* thread_ptr Pointer to thread control blk */
-;/* function_ptr Pointer to return function */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* None */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* _tx_thread_create Create thread service */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_thread_stack_build(TX_THREAD *thread_ptr, VOID (*function_ptr)(VOID))
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_stack_build Cortex-M33/IAR */
+/* 6.1.8 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function builds a stack frame on the supplied thread's stack. */
+/* The stack frame results in a fake interrupt return to the supplied */
+/* function pointer. */
+/* */
+/* INPUT */
+/* */
+/* thread_ptr Pointer to thread control blk */
+/* function_ptr Pointer to return function */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* None */
+/* */
+/* CALLED BY */
+/* */
+/* _tx_thread_create Create thread service */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_thread_stack_build(TX_THREAD *thread_ptr, VOID (*function_ptr)(VOID))
+// {
PUBLIC _tx_thread_stack_build
_tx_thread_stack_build:
-;
-; /* Build a fake interrupt frame. The form of the fake interrupt stack
-; on the Cortex-M33 should look like the following after it is built:
-;
-; Stack Top:
-; LR Interrupted LR (LR at time of PENDSV)
-; r4 Initial value for r4
-; r5 Initial value for r5
-; r6 Initial value for r6
-; r7 Initial value for r7
-; r8 Initial value for r8
-; r9 Initial value for r9
-; r10 Initial value for r10
-; r11 Initial value for r11
-; r0 Initial value for r0 (Hardware stack starts here!!)
-; r1 Initial value for r1
-; r2 Initial value for r2
-; r3 Initial value for r3
-; r12 Initial value for r12
-; lr Initial value for lr
-; pc Initial value for pc
-; xPSR Initial value for xPSR
-;
-; Stack Bottom: (higher memory address) */
-;
- LDR r2, [r0, #16] ; Pickup end of stack area
- BIC r2, r2, #0x7 ; Align frame for 8-byte alignment
- SUB r2, r2, #68 ; Subtract frame size
+ /* Build a fake interrupt frame. The form of the fake interrupt stack
+ on the Cortex-M should look like the following after it is built:
+
+ Stack Top:
+ LR Interrupted LR (LR at time of PENDSV)
+ r4 Initial value for r4
+ r5 Initial value for r5
+ r6 Initial value for r6
+ r7 Initial value for r7
+ r8 Initial value for r8
+ r9 Initial value for r9
+ r10 Initial value for r10
+ r11 Initial value for r11
+ r0 Initial value for r0 (Hardware stack starts here!!)
+ r1 Initial value for r1
+ r2 Initial value for r2
+ r3 Initial value for r3
+ r12 Initial value for r12
+ lr Initial value for lr
+ pc Initial value for pc
+ xPSR Initial value for xPSR
+
+ Stack Bottom: (higher memory address) */
+
+ LDR r2, [r0, #16] // Pickup end of stack area
+ BIC r2, r2, #0x7 // Align frame for 8-byte alignment
+ SUB r2, r2, #68 // Subtract frame size
#ifdef TX_SINGLE_MODE_SECURE
- LDR r3, =0xFFFFFFFD ; Build initial LR value for secure mode
+ LDR r3, =0xFFFFFFFD // Build initial LR value for secure mode
#else
- LDR r3, =0xFFFFFFBC ; Build initial LR value to return to non-secure PSP
+ LDR r3, =0xFFFFFFBC // Build initial LR value to return to non-secure PSP
#endif
- STR r3, [r2, #0] ; Save on the stack
-;
-; /* Actually build the stack frame. */
-;
- MOV r3, #0 ; Build initial register value
- STR r3, [r2, #4] ; Store initial r4
- STR r3, [r2, #8] ; Store initial r5
- STR r3, [r2, #12] ; Store initial r6
- STR r3, [r2, #16] ; Store initial r7
- STR r3, [r2, #20] ; Store initial r8
- STR r3, [r2, #24] ; Store initial r9
- STR r3, [r2, #28] ; Store initial r10
- STR r3, [r2, #32] ; Store initial r11
-;
-; /* Hardware stack follows. */
-;
- STR r3, [r2, #36] ; Store initial r0
- STR r3, [r2, #40] ; Store initial r1
- STR r3, [r2, #44] ; Store initial r2
- STR r3, [r2, #48] ; Store initial r3
- STR r3, [r2, #52] ; Store initial r12
- MOV r3, #0xFFFFFFFF ; Poison EXC_RETURN value
- STR r3, [r2, #56] ; Store initial lr
- STR r1, [r2, #60] ; Store initial pc
- MOV r3, #0x01000000 ; Only T-bit need be set
- STR r3, [r2, #64] ; Store initial xPSR
-;
-; /* Setup stack pointer. */
-; thread_ptr -> tx_thread_stack_ptr = r2;
-;
- STR r2, [r0, #8] ; Save stack pointer in thread's
- ; control block
- BX lr ; Return to caller
-;}
+ STR r3, [r2, #0] // Save on the stack
+
+ /* Actually build the stack frame. */
+
+ MOV r3, #0 // Build initial register value
+ STR r3, [r2, #4] // Store initial r4
+ STR r3, [r2, #8] // Store initial r5
+ STR r3, [r2, #12] // Store initial r6
+ STR r3, [r2, #16] // Store initial r7
+ STR r3, [r2, #20] // Store initial r8
+ STR r3, [r2, #24] // Store initial r9
+ STR r3, [r2, #28] // Store initial r10
+ STR r3, [r2, #32] // Store initial r11
+
+ /* Hardware stack follows. */
+
+ STR r3, [r2, #36] // Store initial r0
+ STR r3, [r2, #40] // Store initial r1
+ STR r3, [r2, #44] // Store initial r2
+ STR r3, [r2, #48] // Store initial r3
+ STR r3, [r2, #52] // Store initial r12
+ MOV r3, #0xFFFFFFFF // Poison EXC_RETURN value
+ STR r3, [r2, #56] // Store initial lr
+ STR r1, [r2, #60] // Store initial pc
+ MOV r3, #0x01000000 // Only T-bit need be set
+ STR r3, [r2, #64] // Store initial xPSR
+
+ /* Setup stack pointer. */
+ // thread_ptr -> tx_thread_stack_ptr = r2;
+
+ STR r2, [r0, #8] // Save stack pointer in thread's
+ // control block
+ BX lr // Return to caller
+// }
END
diff --git a/ports/cortex_m33/iar/src/tx_thread_stack_error_handler.c b/ports/cortex_m33/iar/src/tx_thread_stack_error_handler.c
index 27ac5c42..5c643784 100644
--- a/ports/cortex_m33/iar/src/tx_thread_stack_error_handler.c
+++ b/ports/cortex_m33/iar/src/tx_thread_stack_error_handler.c
@@ -28,8 +28,8 @@
#include "tx_api.h"
#include "tx_thread.h"
-/* Define the global function pointer for stack error handling. If a stack error is
- detected and the application has registered a stack error handler, it will be
+/* Define the global function pointer for stack error handling. If a stack error is
+ detected and the application has registered a stack error handler, it will be
called via this function pointer. */
VOID (*_tx_thread_application_stack_error_handler)(TX_THREAD *thread_ptr);
@@ -38,8 +38,8 @@ VOID (*_tx_thread_application_stack_error_handler)(TX_THREAD *thread_ptr);
/* */
/* FUNCTION RELEASE */
/* */
-/* _tx_thread_stack_error_handler Cortex-M33/IAR */
-/* 6.1 */
+/* _tx_thread_stack_error_handler Cortex-M33 */
+/* 6.1 */
/* AUTHOR */
/* */
/* Scott Larson, Microsoft Corporation */
@@ -75,7 +75,6 @@ VOID (*_tx_thread_application_stack_error_handler)(TX_THREAD *thread_ptr);
/**************************************************************************/
VOID _tx_thread_stack_error_handler(TX_THREAD *thread_ptr)
{
-
#ifndef TX_THREAD_NO_TERMINATE_STACK_ERROR
/* Is there a thread? */
if (thread_ptr)
@@ -88,10 +87,7 @@ VOID _tx_thread_stack_error_handler(TX_THREAD *thread_ptr)
/* Determine if the application has registered an error handler. */
if (_tx_thread_application_stack_error_handler != TX_NULL)
{
-
/* Yes, an error handler is present, simply call the application error handler. */
(_tx_thread_application_stack_error_handler)(thread_ptr);
}
-
}
-
diff --git a/ports/cortex_m33/iar/src/tx_thread_stack_error_notify.c b/ports/cortex_m33/iar/src/tx_thread_stack_error_notify.c
index 328103b2..0ad24a46 100644
--- a/ports/cortex_m33/iar/src/tx_thread_stack_error_notify.c
+++ b/ports/cortex_m33/iar/src/tx_thread_stack_error_notify.c
@@ -35,8 +35,8 @@ extern VOID (*_tx_thread_application_stack_error_handler)(TX_THREAD *thread_ptr)
/* */
/* FUNCTION RELEASE */
/* */
-/* _tx_thread_stack_error_notify Cortex-M33/IAR */
-/* 6.1 */
+/* _tx_thread_stack_error_notify Cortex-M33 */
+/* 6.1 */
/* AUTHOR */
/* */
/* Scott Larson, Microsoft Corporation */
@@ -76,7 +76,6 @@ UINT _tx_thread_stack_error_notify(VOID (*stack_error_handler)(TX_THREAD *threa
TX_INTERRUPT_SAVE_AREA
-
/* Disable interrupts. */
TX_DISABLE
@@ -95,4 +94,3 @@ TX_INTERRUPT_SAVE_AREA
/* Return success to caller. */
return(TX_SUCCESS);
}
-
diff --git a/ports/cortex_m33/iar/src/tx_thread_system_return.s b/ports/cortex_m33/iar/src/tx_thread_system_return.s
index 2f0c2c4e..2b8aea89 100644
--- a/ports/cortex_m33/iar/src/tx_thread_system_return.s
+++ b/ports/cortex_m33/iar/src/tx_thread_system_return.s
@@ -1,87 +1,91 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_system_return Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is target processor specific. It is used to transfer */
-;/* control from a thread back to the ThreadX system. Only a */
-;/* minimal context is saved since the compiler assumes temp registers */
-;/* are going to get slicked by a function call anyway. */
-;/* */
-;/* INPUT */
-;/* */
-;/* None */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* _tx_thread_schedule Thread scheduling loop */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* ThreadX components */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_thread_system_return(VOID)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_system_return Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is target processor specific. It is used to transfer */
+/* control from a thread back to the ThreadX system. Only a */
+/* minimal context is saved since the compiler assumes temp registers */
+/* are going to get slicked by a function call anyway. */
+/* */
+/* INPUT */
+/* */
+/* None */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* _tx_thread_schedule Thread scheduling loop */
+/* */
+/* CALLED BY */
+/* */
+/* ThreadX components */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_thread_system_return(VOID)
+// {
PUBLIC _tx_thread_system_return
-_tx_thread_system_return??rA:
_tx_thread_system_return:
-;
-; /* Return to real scheduler via PendSV. Note that this routine is often
-; replaced with in-line assembly in tx_port.h to improved performance. */
-;
- MOV r0, #0x10000000 ; Load PENDSVSET bit
- MOV r1, #0xE000E000 ; Load NVIC base
- STR r0, [r1, #0xD04] ; Set PENDSVBIT in ICSR
- MRS r0, IPSR ; Pickup IPSR
- CMP r0, #0 ; Is it a thread returning?
- BNE _isr_context ; If ISR, skip interrupt enable
- MRS r1, PRIMASK ; Thread context returning, pickup PRIMASK
- CPSIE i ; Enable interrupts
- MSR PRIMASK, r1 ; Restore original interrupt posture
+ /* Return to real scheduler via PendSV. Note that this routine is often
+ replaced with in-line assembly in tx_port.h to improved performance. */
+
+ MOV r0, #0x10000000 // Load PENDSVSET bit
+ MOV r1, #0xE000E000 // Load NVIC base
+ STR r0, [r1, #0xD04] // Set PENDSVBIT in ICSR
+ MRS r0, IPSR // Pickup IPSR
+ CMP r0, #0 // Is it a thread returning?
+ BNE _isr_context // If ISR, skip interrupt enable
+#ifdef TX_PORT_USE_BASEPRI
+ MRS r1, BASEPRI // Thread context returning, pickup BASEPRI
+ MOV r0, #0
+ MSR BASEPRI, r0 // Enable interrupts
+ MSR BASEPRI, r1 // Restore original interrupt posture
+#else
+ MRS r1, PRIMASK // Thread context returning, pickup PRIMASK
+ CPSIE i // Enable interrupts
+ MSR PRIMASK, r1 // Restore original interrupt posture
+#endif
_isr_context:
- BX lr ; Return to caller
-;}
+ BX lr // Return to caller
+// }
END
diff --git a/ports/cortex_m33/iar/src/tx_timer_interrupt.s b/ports/cortex_m33/iar/src/tx_timer_interrupt.s
index bed202d4..f13e9f0f 100644
--- a/ports/cortex_m33/iar/src/tx_timer_interrupt.s
+++ b/ports/cortex_m33/iar/src/tx_timer_interrupt.s
@@ -1,26 +1,25 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Timer */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Timer */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
EXTERN _tx_timer_time_slice
EXTERN _tx_timer_system_clock
EXTERN _tx_timer_current_ptr
@@ -33,224 +32,220 @@
EXTERN _tx_thread_current_ptr
EXTERN _tx_thread_execute_ptr
EXTERN _tx_thread_preempt_disable
-;
-;
+
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_timer_interrupt Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function processes the hardware timer interrupt. This */
-;/* processing includes incrementing the system clock and checking for */
-;/* time slice and/or timer expiration. If either is found, the */
-;/* the expiration functions are called. */
-;/* */
-;/* INPUT */
-;/* */
-;/* None */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* _tx_timer_expiration_process Timer expiration processing */
-;/* _tx_thread_time_slice Time slice interrupted thread */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* interrupt vector */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_timer_interrupt(VOID)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_timer_interrupt Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function processes the hardware timer interrupt. This */
+/* processing includes incrementing the system clock and checking for */
+/* time slice and/or timer expiration. If either is found, the */
+/* expiration functions are called. */
+/* */
+/* INPUT */
+/* */
+/* None */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* _tx_timer_expiration_process Timer expiration processing */
+/* _tx_thread_time_slice Time slice interrupted thread */
+/* */
+/* CALLED BY */
+/* */
+/* interrupt vector */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_timer_interrupt(VOID)
+// {
PUBLIC _tx_timer_interrupt
_tx_timer_interrupt:
-;
-; /* Upon entry to this routine, it is assumed that the compiler scratch registers are available
-; for use. */
-;
-; /* Increment the system clock. */
-; _tx_timer_system_clock++;
-;
- MOV32 r1, _tx_timer_system_clock ; Pickup address of system clock
- LDR r0, [r1, #0] ; Pickup system clock
- ADD r0, r0, #1 ; Increment system clock
- STR r0, [r1, #0] ; Store new system clock
-;
-; /* Test for time-slice expiration. */
-; if (_tx_timer_time_slice)
-; {
-;
- MOV32 r3, _tx_timer_time_slice ; Pickup address of time-slice
- LDR r2, [r3, #0] ; Pickup time-slice
- CBZ r2, __tx_timer_no_time_slice ; Is it non-active?
- ; Yes, skip time-slice processing
-;
-; /* Decrement the time_slice. */
-; _tx_timer_time_slice--;
-;
- SUB r2, r2, #1 ; Decrement the time-slice
- STR r2, [r3, #0] ; Store new time-slice value
-;
-; /* Check for expiration. */
-; if (__tx_timer_time_slice == 0)
-;
- CBNZ r2, __tx_timer_no_time_slice ; Has it expired?
-;
-; /* Set the time-slice expired flag. */
-; _tx_timer_expired_time_slice = TX_TRUE;
-;
- MOV32 r3, _tx_timer_expired_time_slice ; Pickup address of expired flag
- MOV r0, #1 ; Build expired value
- STR r0, [r3, #0] ; Set time-slice expiration flag
-;
-; }
-;
+
+ /* Upon entry to this routine, it is assumed that the compiler scratch registers are available
+ for use. */
+
+ /* Increment the system clock. */
+ // _tx_timer_system_clock++;
+
+ LDR r1, =_tx_timer_system_clock // Pickup address of system clock
+ LDR r0, [r1, #0] // Pickup system clock
+ ADD r0, r0, #1 // Increment system clock
+ STR r0, [r1, #0] // Store new system clock
+
+ /* Test for time-slice expiration. */
+ // if (_tx_timer_time_slice)
+ // {
+
+ LDR r3, =_tx_timer_time_slice // Pickup address of time-slice
+ LDR r2, [r3, #0] // Pickup time-slice
+ CBZ r2, __tx_timer_no_time_slice // Is it non-active?
+ // Yes, skip time-slice processing
+
+ /* Decrement the time_slice. */
+ // _tx_timer_time_slice--;
+
+ SUB r2, r2, #1 // Decrement the time-slice
+ STR r2, [r3, #0] // Store new time-slice value
+
+ /* Check for expiration. */
+ // if (__tx_timer_time_slice == 0)
+
+ CBNZ r2, __tx_timer_no_time_slice // Has it expired?
+ // No, skip expiration processing
+
+ /* Set the time-slice expired flag. */
+ // _tx_timer_expired_time_slice = TX_TRUE;
+
+ LDR r3, =_tx_timer_expired_time_slice // Pickup address of expired flag
+ MOV r0, #1 // Build expired value
+ STR r0, [r3, #0] // Set time-slice expiration flag
+
+ // }
+
__tx_timer_no_time_slice:
-;
-; /* Test for timer expiration. */
-; if (*_tx_timer_current_ptr)
-; {
-;
- MOV32 r1, _tx_timer_current_ptr ; Pickup current timer pointer address
- LDR r0, [r1, #0] ; Pickup current timer
- LDR r2, [r0, #0] ; Pickup timer list entry
- CBZ r2, __tx_timer_no_timer ; Is there anything in the list?
- ; No, just increment the timer
-;
-; /* Set expiration flag. */
-; _tx_timer_expired = TX_TRUE;
-;
- MOV32 r3, _tx_timer_expired ; Pickup expiration flag address
- MOV r2, #1 ; Build expired value
- STR r2, [r3, #0] ; Set expired flag
- B __tx_timer_done ; Finished timer processing
-;
-; }
-; else
-; {
+
+ /* Test for timer expiration. */
+ // if (*_tx_timer_current_ptr)
+ // {
+
+ LDR r1, =_tx_timer_current_ptr // Pickup current timer pointer address
+ LDR r0, [r1, #0] // Pickup current timer
+ LDR r2, [r0, #0] // Pickup timer list entry
+ CBZ r2, __tx_timer_no_timer // Is there anything in the list?
+ // No, just increment the timer
+
+ /* Set expiration flag. */
+ // _tx_timer_expired = TX_TRUE;
+
+ LDR r3, =_tx_timer_expired // Pickup expiration flag address
+ MOV r2, #1 // Build expired value
+ STR r2, [r3, #0] // Set expired flag
+ B __tx_timer_done // Finished timer processing
+
+ // }
+ // else
+ // {
__tx_timer_no_timer:
-;
-; /* No timer expired, increment the timer pointer. */
-; _tx_timer_current_ptr++;
-;
- ADD r0, r0, #4 ; Move to next timer
-;
-; /* Check for wrap-around. */
-; if (_tx_timer_current_ptr == _tx_timer_list_end)
-;
- MOV32 r3, _tx_timer_list_end ; Pickup addr of timer list end
- LDR r2, [r3, #0] ; Pickup list end
- CMP r0, r2 ; Are we at list end?
- BNE __tx_timer_skip_wrap ; No, skip wrap-around logic
-;
-; /* Wrap to beginning of list. */
-; _tx_timer_current_ptr = _tx_timer_list_start;
-;
- MOV32 r3, _tx_timer_list_start ; Pickup addr of timer list start
- LDR r0, [r3, #0] ; Set current pointer to list start
-;
+
+ /* No timer expired, increment the timer pointer. */
+ // _tx_timer_current_ptr++;
+
+ ADD r0, r0, #4 // Move to next timer
+
+ /* Check for wrap-around. */
+ // if (_tx_timer_current_ptr == _tx_timer_list_end)
+
+ LDR r3, =_tx_timer_list_end // Pickup addr of timer list end
+ LDR r2, [r3, #0] // Pickup list end
+ CMP r0, r2 // Are we at list end?
+ BNE __tx_timer_skip_wrap // No, skip wrap-around logic
+
+ /* Wrap to beginning of list. */
+ // _tx_timer_current_ptr = _tx_timer_list_start;
+
+ LDR r3, =_tx_timer_list_start // Pickup addr of timer list start
+ LDR r0, [r3, #0] // Set current pointer to list start
+
__tx_timer_skip_wrap:
-;
- STR r0, [r1, #0] ; Store new current timer pointer
-; }
-;
+
+ STR r0, [r1, #0] // Store new current timer pointer
+ // }
+
__tx_timer_done:
-;
-;
-; /* See if anything has expired. */
-; if ((_tx_timer_expired_time_slice) || (_tx_timer_expired))
-; {
-;
- MOV32 r3, _tx_timer_expired_time_slice ; Pickup addr of expired flag
- LDR r2, [r3, #0] ; Pickup time-slice expired flag
- CBNZ r2, __tx_something_expired ; Did a time-slice expire?
- ; If non-zero, time-slice expired
- MOV32 r1, _tx_timer_expired ; Pickup addr of other expired flag
- LDR r0, [r1, #0] ; Pickup timer expired flag
- CBZ r0, __tx_timer_nothing_expired ; Did a timer expire?
- ; No, nothing expired
-;
+
+ /* See if anything has expired. */
+ // if ((_tx_timer_expired_time_slice) || (_tx_timer_expired))
+ // {
+
+ LDR r3, =_tx_timer_expired_time_slice // Pickup addr of expired flag
+ LDR r2, [r3, #0] // Pickup time-slice expired flag
+ CBNZ r2, __tx_something_expired // Did a time-slice expire?
+ // If non-zero, time-slice expired
+ LDR r1, =_tx_timer_expired // Pickup addr of other expired flag
+ LDR r0, [r1, #0] // Pickup timer expired flag
+ CBZ r0, __tx_timer_nothing_expired // Did a timer expire?
+ // No, nothing expired
+
__tx_something_expired:
-;
-;
- STMDB sp!, {r0, lr} ; Save the lr register on the stack
- ; and save r0 just to keep 8-byte alignment
-;
-; /* Did a timer expire? */
-; if (_tx_timer_expired)
-; {
-;
- MOV32 r1, _tx_timer_expired ; Pickup addr of expired flag
- LDR r0, [r1, #0] ; Pickup timer expired flag
- CBZ r0, __tx_timer_dont_activate ; Check for timer expiration
- ; If not set, skip timer activation
-;
-; /* Process timer expiration. */
-; _tx_timer_expiration_process();
-;
- BL _tx_timer_expiration_process ; Call the timer expiration handling routine
-;
-; }
+
+ PUSH {r0, lr} // Save the lr register on the stack
+ // and save r0 just to keep 8-byte alignment
+
+ /* Did a timer expire? */
+ // if (_tx_timer_expired)
+ // {
+
+ LDR r1, =_tx_timer_expired // Pickup addr of expired flag
+ LDR r0, [r1, #0] // Pickup timer expired flag
+ CBZ r0, __tx_timer_dont_activate // Check for timer expiration
+ // If not set, skip timer activation
+
+ /* Process timer expiration. */
+ // _tx_timer_expiration_process();
+
+ BL _tx_timer_expiration_process // Call the timer expiration handling routine
+
+ // }
__tx_timer_dont_activate:
-;
-; /* Did time slice expire? */
-; if (_tx_timer_expired_time_slice)
-; {
-;
- MOV32 r3, _tx_timer_expired_time_slice ; Pickup addr of time-slice expired
- LDR r2, [r3, #0] ; Pickup the actual flag
- CBZ r2, __tx_timer_not_ts_expiration ; See if the flag is set
- ; No, skip time-slice processing
-;
-; /* Time slice interrupted thread. */
-; _tx_thread_time_slice();
- BL _tx_thread_time_slice ; Call time-slice processing
- MOV32 r0, _tx_thread_preempt_disable ; Build address of preempt disable flag
- LDR r1, [r0] ; Is the preempt disable flag set?
- CBNZ r1, __tx_timer_skip_time_slice ; Yes, skip the PendSV logic
- MOV32 r0, _tx_thread_current_ptr ; Build current thread pointer address
- LDR r1, [r0] ; Pickup the current thread pointer
- MOV32 r2, _tx_thread_execute_ptr ; Build execute thread pointer address
- LDR r3, [r2] ; Pickup the execute thread pointer
- MOV32 r0, 0xE000ED04 ; Build address of control register
- MOV32 r2, 0x10000000 ; Build value for PendSV bit
- CMP r1, r3 ; Are they the same?
- BEQ __tx_timer_skip_time_slice ; If the same, there was no time-slice performed
- STR r2, [r0] ; Not the same, issue the PendSV for preemption
+ /* Did time slice expire? */
+ // if (_tx_timer_expired_time_slice)
+ // {
+
+ LDR r3, =_tx_timer_expired_time_slice // Pickup addr of time-slice expired
+ LDR r2, [r3, #0] // Pickup the actual flag
+ CBZ r2, __tx_timer_not_ts_expiration // See if the flag is set
+ // No, skip time-slice processing
+
+ /* Time slice interrupted thread. */
+ // _tx_thread_time_slice();
+
+ BL _tx_thread_time_slice // Call time-slice processing
+ LDR r0, =_tx_thread_preempt_disable // Build address of preempt disable flag
+ LDR r1, [r0] // Is the preempt disable flag set?
+ CBNZ r1, __tx_timer_skip_time_slice // Yes, skip the PendSV logic
+ LDR r0, =_tx_thread_current_ptr // Build current thread pointer address
+ LDR r1, [r0] // Pickup the current thread pointer
+ LDR r2, =_tx_thread_execute_ptr // Build execute thread pointer address
+ LDR r3, [r2] // Pickup the execute thread pointer
+ LDR r0, =0xE000ED04 // Build address of control register
+ LDR r2, =0x10000000 // Build value for PendSV bit
+ CMP r1, r3 // Are they the same?
+ BEQ __tx_timer_skip_time_slice // If the same, there was no time-slice performed
+ STR r2, [r0] // Not the same, issue the PendSV for preemption
__tx_timer_skip_time_slice:
-;
-; }
-;
+ // }
+
__tx_timer_not_ts_expiration:
-;
- LDMIA sp!, {r0, lr} ; Recover lr register (r0 is just there for
- ; the 8-byte stack alignment
-;
-; }
-;
+
+ POP {r0, lr} // Recover lr register (r0 is just there for
+ // the 8-byte stack alignment
+
+ // }
+
__tx_timer_nothing_expired:
- DSB ; Complete all memory access
- BX lr ; Return to caller
-;
-;}
+ DSB // Complete all memory access
+ BX lr // Return to caller
+// }
END
diff --git a/ports/cortex_m33/iar/src/txe_thread_secure_stack_allocate.c b/ports/cortex_m33/iar/src/txe_thread_secure_stack_allocate.c
index 3ff6fa68..e67ebacc 100644
--- a/ports/cortex_m33/iar/src/txe_thread_secure_stack_allocate.c
+++ b/ports/cortex_m33/iar/src/txe_thread_secure_stack_allocate.c
@@ -33,8 +33,8 @@
/* */
/* FUNCTION RELEASE */
/* */
-/* _tx_thread_secure_stack_allocate PORTABLE C */
-/* 6.1 */
+/* _tx_thread_secure_stack_allocate Cortex-M33 */
+/* 6.1 */
/* AUTHOR */
/* */
/* Scott Larson, Microsoft Corporation */
@@ -84,7 +84,6 @@ UINT status;
/* Check for an invalid thread pointer. */
if (thread_ptr == TX_NULL)
{
-
/* Thread pointer is invalid, return appropriate error code. */
status = TX_THREAD_ERROR;
}
@@ -92,7 +91,6 @@ UINT status;
/* Now check for invalid thread ID. */
else if (thread_ptr -> tx_thread_id != TX_THREAD_ID)
{
-
/* Thread pointer is invalid, return appropriate error code. */
status = TX_THREAD_ERROR;
}
@@ -111,7 +109,6 @@ UINT status;
/* Determine if everything is okay. */
if (status == TX_SUCCESS)
{
-
/* Call actual secure stack allocate function. */
status = _tx_thread_secure_stack_allocate(thread_ptr, stack_size);
}
@@ -120,4 +117,3 @@ UINT status;
return(status);
#endif
}
-
diff --git a/ports/cortex_m33/iar/src/txe_thread_secure_stack_free.c b/ports/cortex_m33/iar/src/txe_thread_secure_stack_free.c
index f8207c68..9f6ed6b9 100644
--- a/ports/cortex_m33/iar/src/txe_thread_secure_stack_free.c
+++ b/ports/cortex_m33/iar/src/txe_thread_secure_stack_free.c
@@ -33,8 +33,8 @@
/* */
/* FUNCTION RELEASE */
/* */
-/* _txe_thread_secure_stack_free PORTABLE C */
-/* 6.1 */
+/* _txe_thread_secure_stack_free Cortex-M33 */
+/* 6.1 */
/* AUTHOR */
/* */
/* Scott Larson, Microsoft Corporation */
@@ -118,4 +118,3 @@ UINT status;
return(status);
#endif
}
-
diff --git a/ports/cortex_m33/iar/src/tx_thread_context_restore.s b/ports/cortex_m33/iar/src/tx_thread_context_restore.s
index 3217ef18..19f225d6 100644
--- a/ports/cortex_m33/iar/src/tx_thread_context_restore.s
+++ b/ports/cortex_m33/iar/src/tx_thread_context_restore.s
@@ -1,72 +1,77 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
+ EXTERN _tx_execution_isr_exit
SECTION `.text`:CODE:NOROOT(2)
THUMB
;/**************************************************************************/
;/* */
;/* FUNCTION RELEASE */
;/* */
;/* _tx_thread_context_restore Cortex-M33/IAR */
;/* 6.1 */
;/* AUTHOR */
;/* */
;/* Scott Larson, Microsoft Corporation */
;/* */
;/* DESCRIPTION */
;/* */
;/* This function is not needed for Cortex-M. */
;/* */
;/* INPUT */
;/* */
;/* None */
;/* */
;/* OUTPUT */
;/* */
;/* None */
;/* */
;/* CALLS */
;/* */
;/* _tx_thread_schedule Thread scheduling routine */
;/* */
;/* CALLED BY */
;/* */
;/* ISRs Interrupt Service Routines */
;/* */
;/* RELEASE HISTORY */
;/* */
;/* DATE NAME DESCRIPTION */
;/* */
;/* 09-30-2020 Scott Larson Initial Version 6.1 */
;/* */
;/**************************************************************************/
;VOID _tx_thread_context_restore(VOID)
;{
PUBLIC _tx_thread_context_restore
_tx_thread_context_restore:
-;
-; /* Return to interrupt processing. */
-;
+
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ /* Call the ISR exit function to indicate an ISR is complete. */
+ PUSH {r0, lr} // Save return address
+ BL _tx_execution_isr_exit // Call the ISR exit function
+ POP {r0, lr} // Recover return address
+#endif
+
BX lr
-;}
+// }
END
@@ -1,72 +1,77 @@
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_context_restore Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is not needed for Cortex-M. */
-;/* */
-;/* INPUT */
-;/* */
-;/* None */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* _tx_thread_schedule Thread scheduling routine */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* ISRs Interrupt Service Routines */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_thread_context_restore(VOID)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_context_restore Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is not needed for Cortex-M. */
+/* */
+/* INPUT */
+/* */
+/* None */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* [_tx_execution_isr_exit] Execution profiling ISR exit */
+/* */
+/* CALLED BY */
+/* */
+/* ISRs Interrupt Service Routines */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_thread_context_restore(VOID)
+// {
PUBLIC _tx_thread_context_restore
_tx_thread_context_restore:
diff --git a/ports/cortex_m33/iar/src/tx_thread_context_save.s b/ports/cortex_m33/iar/src/tx_thread_context_save.s
index 49f55f4f..1e725265 100644
--- a/ports/cortex_m33/iar/src/tx_thread_context_save.s
+++ b/ports/cortex_m33/iar/src/tx_thread_context_save.s
@@ -1,72 +1,77 @@
-;/**************************************************************************/
-;/* */
-;/* Copyright (c) Microsoft Corporation. All rights reserved. */
-;/* */
-;/* This software is licensed under the Microsoft Software License */
-;/* Terms for Microsoft Azure RTOS. Full text of the license can be */
-;/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
-;/* and in the root directory of this software. */
-;/* */
-;/**************************************************************************/
-;
-;
-;/**************************************************************************/
-;/**************************************************************************/
-;/** */
-;/** ThreadX Component */
-;/** */
-;/** Thread */
-;/** */
-;/**************************************************************************/
-;/**************************************************************************/
-;
-;
+/**************************************************************************/
+/* */
+/* Copyright (c) Microsoft Corporation. All rights reserved. */
+/* */
+/* This software is licensed under the Microsoft Software License */
+/* Terms for Microsoft Azure RTOS. Full text of the license can be */
+/* found in the LICENSE file at https://aka.ms/AzureRTOS_EULA */
+/* and in the root directory of this software. */
+/* */
+/**************************************************************************/
+
+
+/**************************************************************************/
+/**************************************************************************/
+/** */
+/** ThreadX Component */
+/** */
+/** Thread */
+/** */
+/**************************************************************************/
+/**************************************************************************/
+
+ EXTERN _tx_execution_isr_enter
SECTION `.text`:CODE:NOROOT(2)
THUMB
;/**************************************************************************/
;/* */
;/* FUNCTION RELEASE */
;/* */
;/* _tx_thread_context_save Cortex-M33/IAR */
;/* 6.1 */
;/* AUTHOR */
;/* */
;/* Scott Larson, Microsoft Corporation */
;/* */
;/* DESCRIPTION */
;/* */
;/* This function is not needed for Cortex-M. */
;/* */
;/* INPUT */
;/* */
;/* None */
;/* */
;/* OUTPUT */
;/* */
;/* None */
;/* */
;/* CALLS */
;/* */
;/* None */
;/* */
;/* CALLED BY */
;/* */
;/* ISRs */
;/* */
;/* RELEASE HISTORY */
;/* */
;/* DATE NAME DESCRIPTION */
;/* */
;/* 09-30-2020 Scott Larson Initial Version 6.1 */
;/* */
;/**************************************************************************/
;VOID _tx_thread_context_save(VOID)
;{
PUBLIC _tx_thread_context_save
_tx_thread_context_save:
-;
-; /* Return to interrupt processing. */
-;
+
+#if (defined(TX_ENABLE_EXECUTION_CHANGE_NOTIFY) || defined(TX_EXECUTION_PROFILE_ENABLE))
+ /* Call the ISR enter function to indicate an ISR is starting. */
+ PUSH {r0, lr} // Save return address
+ BL _tx_execution_isr_enter // Call the ISR enter function
+ POP {r0, lr} // Recover return address
+#endif
+
BX lr
-;}
+// }
END
@@ -1,72 +1,77 @@
SECTION `.text`:CODE:NOROOT(2)
THUMB
-;/**************************************************************************/
-;/* */
-;/* FUNCTION RELEASE */
-;/* */
-;/* _tx_thread_context_save Cortex-M33/IAR */
-;/* 6.1 */
-;/* AUTHOR */
-;/* */
-;/* Scott Larson, Microsoft Corporation */
-;/* */
-;/* DESCRIPTION */
-;/* */
-;/* This function is not needed for Cortex-M. */
-;/* */
-;/* INPUT */
-;/* */
-;/* None */
-;/* */
-;/* OUTPUT */
-;/* */
-;/* None */
-;/* */
-;/* CALLS */
-;/* */
-;/* None */
-;/* */
-;/* CALLED BY */
-;/* */
-;/* ISRs */
-;/* */
-;/* RELEASE HISTORY */
-;/* */
-;/* DATE NAME DESCRIPTION */
-;/* */
-;/* 09-30-2020 Scott Larson Initial Version 6.1 */
-;/* */
-;/**************************************************************************/
-;VOID _tx_thread_context_save(VOID)
-;{
+/**************************************************************************/
+/* */
+/* FUNCTION RELEASE */
+/* */
+/* _tx_thread_context_save Cortex-M33/IAR */
+/* 6.1 */
+/* AUTHOR */
+/* */
+/* Scott Larson, Microsoft Corporation */
+/* */
+/* DESCRIPTION */
+/* */
+/* This function is not needed for Cortex-M. */
+/* */
+/* INPUT */
+/* */
+/* None */
+/* */
+/* OUTPUT */
+/* */
+/* None */
+/* */
+/* CALLS */
+/* */
+/* [_tx_execution_isr_enter] Execution profiling ISR enter */
+/* */
+/* CALLED BY */
+/* */
+/* ISRs */
+/* */
+/* RELEASE HISTORY */
+/* */
+/* DATE NAME DESCRIPTION */
+/* */
+/* 09-30-2020 Scott Larson Initial Version 6.1 */
+/* */
+/**************************************************************************/
+// VOID _tx_thread_context_save(VOID)
+// {
PUBLIC _tx_thread_context_save
_tx_thread_context_save: